@@ -35,12 +35,12 @@ pugi::xml_node CXmlFile::Load(bool overwriteInvalid)
 
 	GetXmlFile(redirectedName);
 	if (!m_element) {
-		wxString err = wxString::Format(_("The file '%s' could not be loaded."), m_fileName);
+		std::wstring err = fz::sprintf(fztranslate("The file '%s' could not be loaded."), m_fileName);
 		if (m_error.empty()) {
-			err += wxString(_T("\n")) + _("Make sure the file can be accessed and is a well-formed XML document.");
+			err += L"\n" + fztranslate("Make sure the file can be accessed and is a well-formed XML document.");
 		}
 		else {
-			err += _T("\n") + m_error;
+			err += L"\n" + m_error;
 		}
 
 		// Try the backup file
@@ -74,19 +74,19 @@ pugi::xml_node CXmlFile::Load(bool overwriteInvalid)
 		bool res;
 		{
 			wxLogNull null;
-			res = wxCopyFile(redirectedName + _T("~"), redirectedName);
+			res = wxCopyFile(redirectedName + L"~", redirectedName);
 		}
 		if (!res) {
 			// Could not restore backup, give up.
 			Close();
-			m_error = err.ToStdWstring();
-			m_error += _T("\n") + wxString::Format(_("The valid backup file %s could not be restored"), redirectedName + _T("~")).ToStdWstring();
+			m_error = err;
+			m_error += L"\n" + fz::sprintf(fztranslate("The valid backup file %s could not be restored"), redirectedName + L"~");
 			m_modificationTime.clear();
 			return m_element;
 		}
 
 		// We no longer need the backup
-		wxRemoveFile(redirectedName + _T("~"));
+		fz::remove_file(fz::to_native(redirectedName + L"~"));
 		m_error.clear();
 	}
 
@@ -273,7 +273,7 @@ bool CXmlFile::SaveXmlFile()
 
 	bool success = flushing_xml_writer::save(m_document, redirectedName.ToStdWstring());
 	if (!success) {
-		wxRemoveFile(redirectedName);
+		fz::remove_file(fz::to_native(redirectedName));
 		if (exists) {
 			wxLogNull null;
 			wxRenameFile(redirectedName + _T("~"), redirectedName);
@@ -283,7 +283,7 @@ bool CXmlFile::SaveXmlFile()
 	}
 
 	if (exists) {
-		wxRemoveFile(redirectedName + _T("~"));
+		fz::remove_file(fz::to_native(redirectedName + L"~"));
 	}
 
 	return true;
@@ -345,7 +345,7 @@ bool GetServer(pugi::xml_node node, ServerWithCredentials & server)
 				}
 				else if (encoding == _T("crypt")) {
 					pass = fz::to_wstring_from_utf8(passElement.child_value());
-					server.credentials.encrypted_ = public_key::from_base64(passElement.attribute("pubkey").value());
+					server.credentials.encrypted_ = fz::public_key::from_base64(passElement.attribute("pubkey").value());
 					if (!server.credentials.encrypted_) {
 						pass.clear();
 						server.SetLogonType(LogonType::ask);
